@@ -1,15 +1,14 @@
-# 
+#
 # This file is part of CM-Permutation
-# 
-# This software is copyright (c) 2010 by Stefan Petrea.
-# 
+#
+# This software is copyright (c) 2011 by Stefan Petrea.
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use strict;
 use warnings;
 package CM::Group::Altern;
-our $VERSION = '0.4';
 use Moose;
 extends 'CM::Group::Sym';
 
@@ -17,10 +16,6 @@ extends 'CM::Group::Sym';
 
 CM::Group::Altern - The alternating group of degree n.
 
-=head1 VERSION
-
-version 0.4
-
 =head1 DESCRIPTION
 
 CM::Group::Altern is an implementation of the Alternating Group A_n which is a subgroup of the symmetric group S_n
@@ -70,17 +65,19 @@ sub _builder_order {
 
 
 # TODO: must fix this with method modifiers - overrides method from Sym.pm
-sub compute_elements {
+sub _compute_elements {
     my ($self) = @_;
-    my $label = 0;
-    my @permutations;
-    my $p = new Algorithm::Permute([1..$self->n]);
-    while (my @new_perm = $p->next) {
-        my $new_one = CM::Permutation->new(@new_perm);
-        next unless $new_one->even_odd == 0; # only even permutations
-        $self->add_to_elements($new_one);
-    };
+	sub {
+		my $label = 0;
+		my @permutations;
+		my $p = new Algorithm::Permute([1..$self->n]);
+		while (my @new_perm = $p->next) {
+			my $new_one = CM::Permutation->new(@new_perm);
+			next unless $new_one->even_odd == 0; # only even permutations
+			$self->add_to_elements($new_one);
+		};
+	}
 }
 
 
-1;
\ No newline at end of file
+1;
